@@ -3,7 +3,9 @@
 from django.views import generic
 from django.views.generic.edit import CreateView, UpdateView
 from django.views.generic import TemplateView, ListView
+from django.db.models import Sum
 from django.contrib.auth.mixins import LoginRequiredMixin
+from django.contrib.auth import get_user_model
 from django.apps import apps
 from django.shortcuts import get_object_or_404
 from django.urls import reverse
@@ -52,19 +54,19 @@ class PagedFilteredTableView(SingleTableMixin, FilterView):
 
     # pylint: disable=not-callable,attribute-defined-outside-init
     def get_queryset(self):
-        qs = super(PagedFilteredTableView, self).get_queryset()
+        qs = super().get_queryset()
         self.filter = self.filterset_class(self.request.GET, queryset=qs)
         self.filter.form.helper = self.formhelper_class()
         return self.filter.qs
 
  #   def get_table(self, **kwargs):
- #       table = super(PagedFilteredTableView, self).get_table()
+ #       table = super().get_table()
  #       RequestConfig(self.request, paginate={'page': self.kwargs['page'],
  #                           "per_page": self.paginate_by}).configure(table)
  #       return table
 
     def get_context_data(self, **kwargs):
-        context = super(PagedFilteredTableView, self).get_context_data()
+        context = super().get_context_data()
         context[self.context_filter_name] = self.filter
         return context
 
@@ -218,7 +220,7 @@ class CameraCreate(LoginRequiredMixin, CreateView):
     template_name = 'create.html'
 
     def get_initial(self):
-        initial = super(CameraCreate, self).get_initial()
+        initial = super().get_initial()
         if 'cameramodel' in self.request.GET:
             initial.update({'cameramodel': self.request.GET['cameramodel']})
         return initial
@@ -521,7 +523,7 @@ class LensCreate(LoginRequiredMixin, CreateView):
     template_name = 'create.html'
 
     def get_initial(self):
-        initial = super(LensCreate, self).get_initial()
+        initial = super().get_initial()
         if 'lensmodel' in self.request.GET:
             initial.update({'lensmodel': self.request.GET['lensmodel']})
         return initial
@@ -1113,8 +1115,83 @@ class StatsView(TemplateView):
                 'item': "manufacturers in CameraHub",
                 'value': Manufacturer.objects.count
             },
+            {
+                'image': "svg/person.svg",
+                'item': "users on CameraHub",
+                'value': get_user_model().objects.count
+            },
         ]
 
+        oldestcamera = CameraModel.objects.filter(
+            introduced__isnull=False).order_by('introduced').first()
+        if oldestcamera:
+            stats.append(
+                {
+                    'image': "svg/vintagecamera.svg",
+                    'url': oldestcamera.get_absolute_url,
+                    'item': "oldest camera on CameraHub",
+                    'subheading': oldestcamera.introduced,
+                    'value': oldestcamera,
+                }
+            )
+
+        heaviestcamera = CameraModel.objects.filter(
+            weight__isnull=False).order_by('weight').last()
+        if heaviestcamera:
+            stats.append(
+                {
+                    'image': "svg/bigcamera.svg",
+                    'url': heaviestcamera.get_absolute_url,
+                    'item': "heaviest camera on CameraHub",
+                    'subheading': str(heaviestcamera.weight) + 'g',
+                    'value': heaviestcamera
+                }
+            )
+
+        longestlens = LensModel.objects.filter(
+            max_focal_length__isnull=False).order_by('max_focal_length').last()
+        if longestlens:
+            stats.append(
+                {
+                    'image': "svg/lens.svg",
+                    'url': longestlens.get_absolute_url,
+                    'item': "longest lens on CameraHub",
+                    'subheading': str(longestlens.max_focal_length) + 'mm',
+                    'value': longestlens
+                }
+            )
+
+        fastestlens = LensModel.objects.filter(
+            max_aperture__isnull=False).order_by('max_aperture').first()
+        if fastestlens:
+            stats.append(
+                {
+                    'image': "svg/teleconverter.svg",
+                    'url': fastestlens.get_absolute_url,
+                    'item': "fastest lens on CameraHub",
+                    'subheading': 'f/' + str(fastestlens.max_aperture),
+                    'value': fastestlens
+                }
+            )
+
+        stats.append(
+            {
+                'image': "svg/weight.svg",
+                'url': reverse('cameramodel-list'),
+                'item': "total weight of all cameras in CameraHub",
+                'value': str(round((CameraModel.objects.all().aggregate(totalweight=Sum('weight'))['totalweight'] or 0.00)/1000)) + 'kg',
+            }
+        )
+
+        stats.append(
+            {
+                'image': "svg/ruler.svg",
+                'url': reverse('lensmodel-list'),
+                'item': "total length of all lenses in CameraHub, laid end to end",
+                'value': str(round((LensModel.objects.all().aggregate(totallength=Sum('length'))['totallength'] or 0.00)/1000)) + 'm',
+            }
+        )
+
         context['stats'] = stats
         context['title'] = "Public stats"
         return context
@@ -1129,13 +1206,25 @@ class MyStatsView(LoginRequiredMixin, TemplateView):
             {
                 'image': "svg/camera.svg",
                 'url': reverse('camera-list'),
-                'item': "cameras in your collection",
+                'item': "cameras in your collection right now",
+                'value': Camera.objects.filter(owner=self.request.user, own=True).count,
+            },
+            {
+                'image': "svg/camera.svg",
+                'url': reverse('camera-list'),
+                'item': "cameras ever in your collection",
                 'value': Camera.objects.filter(owner=self.request.user).count,
             },
             {
                 'image': "svg/lens.svg",
                 'url': reverse('lens-list'),
-                'item': "lenses in your collection",
+                'item': "lenses in your collection right now",
+                'value': Lens.objects.filter(owner=self.request.user, own=True).count,
+            },
+            {
+                'image': "svg/lens.svg",
+                'url': reverse('lens-list'),
+                'item': "lenses ever in your collection",
                 'value': Lens.objects.filter(owner=self.request.user).count,
             },
             {
